#include "darwin_robot.h"
#include "darwin_robot_exceptions.h"

#include <iostream>

//std::string robot_device="A603LOBS";
std::string robot_device="A4008atn";

int main(int argc, char *argv[])
{
  int num_servos,i,j;
  unsigned int present_servos;
  std::vector<unsigned char> servos;
  std::vector<double> angles,speeds,accels;

  try{
    CDarwinRobot darwin("Darwin",robot_device,1000000,0x02);
    num_servos=darwin.mm_get_num_servos();
    std::cout << "Found " << num_servos << " servos " << std::endl;
    present_servos=darwin.mm_get_present_servos();
    std::cout << "Present servos: " << std::hex << "0x" << present_servos << std::dec << std::endl;
    darwin.mm_enable_power();
    for(i=0;i<MAX_NUM_SERVOS;i++)
    {
      if(present_servos&(0x00000001<<i))
      {
        darwin.mm_enable_servo(i);
        darwin.mm_assign_module(i,DARWIN_MM_JOINTS); 
      }
    }
    darwin.mm_start();
    for(j=0;j<4;j++)
    { 
      servos.clear();
      angles.clear();
      speeds.clear();
      accels.clear();
      for(i=0;i<MAX_NUM_SERVOS;i++)
      {
        if(present_servos&(0x00000001<<i))
        {
          servos.push_back(i);
          angles.push_back(45.0);
          speeds.push_back(10.0*j);
          accels.push_back(10.0*j);
        }
      }
      std::cout << "Start joint_motion ..." << std::endl;
      darwin.joints_load((joints_grp_t)j,servos,angles,speeds,accels);
      darwin.joints_start((joints_grp_t)j);
      while(darwin.joints_are_moving((joints_grp_t)j))
      {
        std::cout << "moving joints ..." << std::endl;
        usleep(100000);
      }
      std::cout << "done" << std::endl;
      servos.clear();
      angles.clear();
      speeds.clear();
      accels.clear();
      for(i=0;i<MAX_NUM_SERVOS;i++)
      {
        if(present_servos&(0x00000001<<i))
        {
          servos.push_back(i);
          angles.push_back(-45.0);
          speeds.push_back(10.0*j);
          accels.push_back(10.0*j);
        }
      }
      darwin.joints_load((joints_grp_t)j,servos,angles,speeds,accels);
      darwin.joints_start((joints_grp_t)j);
      while(darwin.joints_are_moving((joints_grp_t)j))
      {
        std::cout << "moving joints ..." << std::endl;
        usleep(100000);
      }
    }
    darwin.mm_stop();
    darwin.mm_disable_power();
  }catch(CException &e){
    std::cout << e.what() << std::endl;
  }
}
